@@ -86,14 +86,14 @@
 
 // TODO: remove these and use values from config.h instead.
 #define TOOL_NAME "sp-startup-time"
-#define TOOL_VERS "0.0.8"
+#define TOOL_VERS "0.1.0"
 
 /* - - - - - - - - - - - - - - - - - - - *
  * Private environment cache is
  * updated from this file
  * - - - - - - - - - - - - - - - - - - - */
 
-#define ENV_FILE_PATH "/tmp/startup.env"
+#define ENV_FILE_PATH "/etc/libstartup.conf"
 
 /* - - - - - - - - - - - - - - - - - - - *
  * Calculate number of entries in
@@ -243,8 +243,8 @@ static int readfile(const char *path, char *dest, size_t size)
 {
   int    done = -1;
   int    file = -1;
-
-  // Note: we are silent about any errors
+  
+// Note: we are silent about any errors
   if( (file = open(path,O_RDONLY)) != -1 )
   {
     done = read(file, dest, size-1);
@@ -331,10 +331,12 @@ static void env_update_from_real(void)
   for( int i = 0; env_key[i]; ++i )
   {
     const char *val = getenv(env_key[i]);
-    free(env_val[i]);
-    env_val[i] = val ? strdup(val) : 0;
-    
-    debug_msg("env init: %s=%s\n", env_key[i], env_val[i] ? env_val[i] : "<null>");
+    if (val != NULL)
+    {
+      free(env_val[i]);
+      env_val[i] = strdup(val);
+      debug_msg("env init: %s=%s\n", env_key[i], env_val[i] ? env_val[i] : "<null>");
+    }
   }
 }
 
@@ -344,6 +346,9 @@ static void env_update_from_real(void)
 
 static void env_update_from_file(const char *path)
 {
+  /* FIXME: If user modifies the configuration file to be larger than 1 kB,
+     the rest will currently just be silently ignored... */
+
   char temp[1024];
   
   if( readfile(path, temp, sizeof temp) != -1 )
@@ -975,8 +980,8 @@ static void lib_init(void)
 
   LOG_ENTER
 
-  env_update_from_real();  
   env_update_from_file(ENV_FILE_PATH);
+  env_update_from_real();
   
   lib_logpath_set();
   atexit(lib_exit);
